@@ -35,7 +35,7 @@ namespace StepCore {
 typedef Eigen::SparseMatrix<double> SparseColMatrix;
 typedef Eigen::SparseMatrix<double,Eigen::RowMajor> SparseRowMatrix;
 // a sparse matrix with efficient write facilities
-typedef Eigen::DynamicSparseMatrix<double,Eigen::RowMajor> DynSparseRowMatrix;
+typedef Eigen::SparseMatrix<double,Eigen::RowMajor> DynSparseRowMatrix;
 typedef Eigen::Map<Eigen::VectorXd> MappedVector;
 
 ///////////////// Color
@@ -64,13 +64,13 @@ template<> inline Color stringToType(const QString& s, bool *ok)
 ///////////////// QByteArray
 template<> inline QString typeToString(const QByteArray& v)
 {
-    return QString::fromAscii(v.toBase64());
+    return QString::fromLatin1(v.toBase64());
 }
 
 template<> inline QByteArray stringToType(const QString& s, bool *ok)
 {
     if(ok) *ok = true;
-    return QByteArray::fromBase64(s.toAscii());
+    return QByteArray::fromBase64(s.toLatin1());
 }
 
 ///////////////// Vector2d
